==> jwinner-base-0.0.3-sources.jar: itez/plat/base/model/base/BaseUser.java <==
package itez.plat.base.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseUser<M extends BaseUser<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setType(java.lang.Integer type) {
		set("type", type);
		return (M)this;
	}
	
	public java.lang.Integer getType() {
		return getInt("type");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setPhone(java.lang.String phone) {
		set("phone", phone);
		return (M)this;
	}
	
	public java.lang.String getPhone() {
		return getStr("phone");
	}

	public M setPhoneVali(java.lang.Integer phoneVali) {
		set("phoneVali", phoneVali);
		return (M)this;
	}
	
	public java.lang.Integer getPhoneVali() {
		return getInt("phoneVali");
	}

	public M setEmail(java.lang.String email) {
		set("email", email);
		return (M)this;
	}
	
	public java.lang.String getEmail() {
		return getStr("email");
	}

	public M setEmailVali(java.lang.Integer emailVali) {
		set("emailVali", emailVali);
		return (M)this;
	}
	
	public java.lang.Integer getEmailVali() {
		return getInt("emailVali");
	}

	public M setLoginName(java.lang.String loginName) {
		set("loginName", loginName);
		return (M)this;
	}
	
	public java.lang.String getLoginName() {
		return getStr("loginName");
	}

	public M setLoginPass(java.lang.String loginPass) {
		set("loginPass", loginPass);
		return (M)this;
	}
	
	public java.lang.String getLoginPass() {
		return getStr("loginPass");
	}

	public M setSalt(java.lang.String salt) {
		set("salt", salt);
		return (M)this;
	}
	
	public java.lang.String getSalt() {
		return getStr("salt");
	}

	public M setLevel(java.lang.Integer level) {
		set("level", level);
		return (M)this;
	}
	
	public java.lang.Integer getLevel() {
		return getInt("level");
	}

	public M setDeptId(java.lang.String deptId) {
		set("deptId", deptId);
		return (M)this;
	}
	
	public java.lang.String getDeptId() {
		return getStr("deptId");
	}

	public M setPostId(java.lang.String postId) {
		set("postId", postId);
		return (M)this;
	}
	
	public java.lang.String getPostId() {
		return getStr("postId");
	}

	public M setCoef(java.math.BigDecimal coef) {
		set("coef", coef);
		return (M)this;
	}
	
	public java.math.BigDecimal getCoef() {
		return get("coef");
	}

	public M setRoleIds(java.lang.String roleIds) {
		set("roleIds", roleIds);
		return (M)this;
	}
	
	public java.lang.String getRoleIds() {
		return getStr("roleIds");
	}

	public M setHeader(java.lang.String header) {
		set("header", header);
		return (M)this;
	}
	
	public java.lang.String getHeader() {
		return getStr("header");
	}

	public M setRemark(java.lang.String remark) {
		set("remark", remark);
		return (M)this;
	}
	
	public java.lang.String getRemark() {
		return getStr("remark");
	}

	public M setSex(java.lang.String sex) {
		set("sex", sex);
		return (M)this;
	}
	
	public java.lang.String getSex() {
		return getStr("sex");
	}

	public M setLanguage(java.lang.String language) {
		set("language", language);
		return (M)this;
	}
	
	public java.lang.String getLanguage() {
		return getStr("language");
	}

	public M setCountry(java.lang.String country) {
		set("country", country);
		return (M)this;
	}
	
	public java.lang.String getCountry() {
		return getStr("country");
	}

	public M setProvince(java.lang.String province) {
		set("province", province);
		return (M)this;
	}
	
	public java.lang.String getProvince() {
		return getStr("province");
	}

	public M setCity(java.lang.String city) {
		set("city", city);
		return (M)this;
	}
	
	public java.lang.String getCity() {
		return getStr("city");
	}

	public M setFollowed(java.lang.Integer followed) {
		set("followed", followed);
		return (M)this;
	}
	
	public java.lang.Integer getFollowed() {
		return getInt("followed");
	}

	public M setFollowDate(java.util.Date followDate) {
		set("followDate", followDate);
		return (M)this;
	}
	
	public java.util.Date getFollowDate() {
		return get("followDate");
	}

	public M setWxOpenId(java.lang.String wxOpenId) {
		set("wxOpenId", wxOpenId);
		return (M)this;
	}
	
	public java.lang.String getWxOpenId() {
		return getStr("wxOpenId");
	}

	public M setWxeOpenId(java.lang.String wxeOpenId) {
		set("wxeOpenId", wxeOpenId);
		return (M)this;
	}
	
	public java.lang.String getWxeOpenId() {
		return getStr("wxeOpenId");
	}

	public M setWxaOpenId(java.lang.String wxaOpenId) {
		set("wxaOpenId", wxaOpenId);
		return (M)this;
	}
	
	public java.lang.String getWxaOpenId() {
		return getStr("wxaOpenId");
	}

	public M setWxaSessionKey(java.lang.String wxaSessionKey) {
		set("wxaSessionKey", wxaSessionKey);
		return (M)this;
	}
	
	public java.lang.String getWxaSessionKey() {
		return getStr("wxaSessionKey");
	}

	public M setWxaFormId(java.lang.String wxaFormId) {
		set("wxaFormId", wxaFormId);
		return (M)this;
	}
	
	public java.lang.String getWxaFormId() {
		return getStr("wxaFormId");
	}

	public M setUnionId(java.lang.String unionId) {
		set("unionId", unionId);
		return (M)this;
	}
	
	public java.lang.String getUnionId() {
		return getStr("unionId");
	}

	public M setTmid(java.lang.String tmid) {
		set("tmid", tmid);
		return (M)this;
	}
	
	public java.lang.String getTmid() {
		return getStr("tmid");
	}

	public M setCdate(java.util.Date cdate) {
		set("cdate", cdate);
		return (M)this;
	}
	
	public java.util.Date getCdate() {
		return get("cdate");
	}

	public M setUdate(java.util.Date udate) {
		set("udate", udate);
		return (M)this;
	}
	
	public java.util.Date getUdate() {
		return get("udate");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}

==> jwinner-base-0.0.6-sources.jar: itez/plat/base/model/base/BaseUser.java <==
package itez.plat.base.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseUser<M extends BaseUser<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setIdNum(java.lang.String idNum) {
		set("idNum", idNum);
		return (M)this;
	}
	
	public java.lang.String getIdNum() {
		return getStr("idNum");
	}

	public M setNum(java.lang.String num) {
		set("num", num);
		return (M)this;
	}
	
	public java.lang.String getNum() {
		return getStr("num");
	}

	public M setMember(java.lang.Integer member) {
		set("member", member);
		return (M)this;
	}
	
	public java.lang.Integer getMember() {
		return getInt("member");
	}

	public M setType(java.lang.String type) {
		set("type", type);
		return (M)this;
	}
	
	public java.lang.String getType() {
		return getStr("type");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setPhone(java.lang.String phone) {
		set("phone", phone);
		return (M)this;
	}
	
	public java.lang.String getPhone() {
		return getStr("phone");
	}

	public M setPhoneVali(java.lang.Integer phoneVali) {
		set("phoneVali", phoneVali);
		return (M)this;
	}
	
	public java.lang.Integer getPhoneVali() {
		return getInt("phoneVali");
	}

	public M setEmail(java.lang.String email) {
		set("email", email);
		return (M)this;
	}
	
	public java.lang.String getEmail() {
		return getStr("email");
	}

	public M setEmailVali(java.lang.Integer emailVali) {
		set("emailVali", emailVali);
		return (M)this;
	}
	
	public java.lang.Integer getEmailVali() {
		return getInt("emailVali");
	}

	public M setLoginName(java.lang.String loginName) {
		set("loginName", loginName);
		return (M)this;
	}
	
	public java.lang.String getLoginName() {
		return getStr("loginName");
	}

	public M setLoginPass(java.lang.String loginPass) {
		set("loginPass", loginPass);
		return (M)this;
	}
	
	public java.lang.String getLoginPass() {
		return getStr("loginPass");
	}

	public M setSalt(java.lang.String salt) {
		set("salt", salt);
		return (M)this;
	}
	
	public java.lang.String getSalt() {
		return getStr("salt");
	}

	public M setLevel(java.lang.Integer level) {
		set("level", level);
		return (M)this;
	}
	
	public java.lang.Integer getLevel() {
		return getInt("level");
	}

	public M setDeptId(java.lang.String deptId) {
		set("deptId", deptId);
		return (M)this;
	}
	
	public java.lang.String getDeptId() {
		return getStr("deptId");
	}

	public M setPostId(java.lang.String postId) {
		set("postId", postId);
		return (M)this;
	}
	
	public java.lang.String getPostId() {
		return getStr("postId");
	}

	public M setCoef(java.math.BigDecimal coef) {
		set("coef", coef);
		return (M)this;
	}
	
	public java.math.BigDecimal getCoef() {
		return get("coef");
	}

	public M setRoleIds(java.lang.String roleIds) {
		set("roleIds", roleIds);
		return (M)this;
	}
	
	public java.lang.String getRoleIds() {
		return getStr("roleIds");
	}

	public M setHeader(java.lang.String header) {
		set("header", header);
		return (M)this;
	}
	
	public java.lang.String getHeader() {
		return getStr("header");
	}

	public M setRemark(java.lang.String remark) {
		set("remark", remark);
		return (M)this;
	}
	
	public java.lang.String getRemark() {
		return getStr("remark");
	}

	public M setSex(java.lang.String sex) {
		set("sex", sex);
		return (M)this;
	}
	
	public java.lang.String getSex() {
		return getStr("sex");
	}

	public M setLanguage(java.lang.String language) {
		set("language", language);
		return (M)this;
	}
	
	public java.lang.String getLanguage() {
		return getStr("language");
	}

	public M setCountry(java.lang.String country) {
		set("country", country);
		return (M)this;
	}
	
	public java.lang.String getCountry() {
		return getStr("country");
	}

	public M setProvince(java.lang.String province) {
		set("province", province);
		return (M)this;
	}
	
	public java.lang.String getProvince() {
		return getStr("province");
	}

	public M setCity(java.lang.String city) {
		set("city", city);
		return (M)this;
	}
	
	public java.lang.String getCity() {
		return getStr("city");
	}

	public M setFollowed(java.lang.Integer followed) {
		set("followed", followed);
		return (M)this;
	}
	
	public java.lang.Integer getFollowed() {
		return getInt("followed");
	}

	public M setFollowDate(java.util.Date followDate) {
		set("followDate", followDate);
		return (M)this;
	}
	
	public java.util.Date getFollowDate() {
		return get("followDate");
	}

	public M setWxOpenId(java.lang.String wxOpenId) {
		set("wxOpenId", wxOpenId);
		return (M)this;
	}
	
	public java.lang.String getWxOpenId() {
		return getStr("wxOpenId");
	}

	public M setWxeOpenId(java.lang.String wxeOpenId) {
		set("wxeOpenId", wxeOpenId);
		return (M)this;
	}
	
	public java.lang.String getWxeOpenId() {
		return getStr("wxeOpenId");
	}

	public M setWxaOpenId(java.lang.String wxaOpenId) {
		set("wxaOpenId", wxaOpenId);
		return (M)this;
	}
	
	public java.lang.String getWxaOpenId() {
		return getStr("wxaOpenId");
	}

	public M setWxaSessionKey(java.lang.String wxaSessionKey) {
		set("wxaSessionKey", wxaSessionKey);
		return (M)this;
	}
	
	public java.lang.String getWxaSessionKey() {
		return getStr("wxaSessionKey");
	}

	public M setWxaFormId(java.lang.String wxaFormId) {
		set("wxaFormId", wxaFormId);
		return (M)this;
	}
	
	public java.lang.String getWxaFormId() {
		return getStr("wxaFormId");
	}

	public M setUnionId(java.lang.String unionId) {
		set("unionId", unionId);
		return (M)this;
	}
	
	public java.lang.String getUnionId() {
		return getStr("unionId");
	}

	public M setTmid(java.lang.String tmid) {
		set("tmid", tmid);
		return (M)this;
	}
	
	public java.lang.String getTmid() {
		return getStr("tmid");
	}

	public M setCdate(java.util.Date cdate) {
		set("cdate", cdate);
		return (M)this;
	}
	
	public java.util.Date getCdate() {
		return get("cdate");
	}

	public M setUdate(java.util.Date udate) {
		set("udate", udate);
		return (M)this;
	}
	
	public java.util.Date getUdate() {
		return get("udate");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}
